@@ -38,16 +38,18 @@ class KReplacePrivate;
  *  // This creates a replace-on-prompt dialog if needed.
  *  m_replace = new KReplace(pattern, replacement, options, this);
  *
- *  // Connect signals to code which handles highlighting
- *  // of found text, and on-the-fly replacement.
- *  connect( m_replace, SIGNAL( highlight( const QString &, int, int ) ),
- *          this, SLOT( slotHighlight( const QString &, int, int ) ) );
+ *  // Connect signals to code which handles highlighting of found text, and
+ *  // on-the-fly replacement.
+ *  connect(m_replace, &KFind::textFound, this, [this](const QString &text, int matchingIndex, int matchedLength) {
+ *      slotHighlight(text, matchingIndex, matchedLength);
+ *  });
  *  // Connect findNext signal - called when pressing the button in the dialog
  *  connect( m_replace, SIGNAL( findNext() ),
  *          this, SLOT( slotReplaceNext() ) );
- *  // Connect replace signal - called when doing a replacement
- *  connect( m_replace, SIGNAL( replace(const QString &, int, int, int) ),
- *          this, SLOT( slotReplace(const QString &, int, int, int) ) );
+ *  // Connect to the textReplaced() signal - emitted when a replacement is done
+ *  connect( m_replace, &KReplace::textReplaced, this, [this](const QString &text, int replacementIndex, int replacedLength, int matchedLength) {
+ *      slotReplace(text, replacementIndex, replacedLength, matchedLength);
+ *  });
  * \endcode
  *  Then initialize the variables determining the "current position"
  *  (to the cursor, if the option FromCursor is set,
@@ -84,13 +86,11 @@ class KReplacePrivate;
  *  unless you gave it a parent widget on construction.
  *
  */
-class KTEXTWIDGETS_EXPORT KReplace :
-    public KFind
+class KTEXTWIDGETS_EXPORT KReplace : public KFind
 {
     Q_OBJECT
 
 public:
-
     /**
      * Only use this constructor if you don't use KFindDialog, or if
      * you use it as a modal dialog.
@@ -108,7 +108,8 @@ public:
 
     /**
      * Return the number of replacements made (i.e. the number of times
-     * the replace signal was emitted).
+     * the textReplaced() signal was emitted).
+     *
      * Can be used in a dialog box to tell the user how many replacements were made.
      * The final dialog does so already, unless you used setDisplayFinalDialog(false).
      */
@@ -123,7 +124,7 @@ public:
 
     /**
      * Walk the text fragment (e.g. kwrite line, kspread cell) looking for matches.
-     * For each match, if prompt-on-replace is specified, emits the highlight() signal
+     * For each match, if prompt-on-replace is specified, emits the textFound() signal
      * and displays the prompt-for-replace dialog before doing the replace.
      */
     Result replace();
@@ -159,23 +160,6 @@ public:
      */
     static int replace(QString &text, const QString &pattern, const QString &replacement, int index, long options, int *replacedLength);
 
-#if KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(5, 70)
-    /**
-     * This is an overloaded function provided for use with QRegExp regular expressions.
-     *
-     * @param text The string to search.
-     * @param pattern The QRegExp object used for searching.
-     * @param replacement The replacement string to insert into the text.
-     * @param index The starting index into the string.
-     * @param options The options to use.
-     * @param replacedLength Output parameter, contains the length of the replaced string.
-     * Not always the same as replacement.length(), when backreferences are used.
-     * @return The index at which a match was found, or -1 if no match was found.
-     * @deprecated Since 5.70, for lack of direct use
-    */
-    static int replace(QString &text, const QRegExp &pattern, const QString &replacement, int index, long options, int *replacedLength);
-#endif
-
     /**
      * Returns true if we should restart the search from scratch.
      * Can ask the user, or return false (if we already searched/replaced the
@@ -199,29 +183,25 @@ public:
     void displayFinalDialog() const override;
 
 Q_SIGNALS:
-
     /**
-     * Connect to this slot to implement updating of replaced text during the replace
+     * Connect to this signal to implement updating of replaced text during the replace
      * operation.
      *
      * Extra care must be taken to properly implement the "no prompt-on-replace" case.
-     * For instance highlight isn't emitted in that case (some code might rely on it),
-     * and for performance reasons one should repaint after replace() ONLY if
-     * prompt-on-replace was selected.
+     * For instance, the textFound() signal isn't emitted in that case (some code
+     * might rely on it), and for performance reasons one should repaint after
+     * replace() ONLY if prompt-on-replace was selected.
      *
-     * @param text The text, in which the replacement has already been done.
+     * @param text The text, in which the replacement has already been done
      * @param replacementIndex Starting index of the matched substring
      * @param replacedLength Length of the replacement string
      * @param matchedLength Length of the matched string
+     *
+     * @since 5.83
      */
-    void replace(const QString &text, int replacementIndex, int replacedLength, int matchedLength);
+    void textReplaced(const QString &text, int replacementIndex, int replacedLength, int matchedLength);
 
 private:
-    friend class KReplacePrivate;
-    KReplacePrivate *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_slotSkip())
-    Q_PRIVATE_SLOT(d, void _k_slotReplace())
-    Q_PRIVATE_SLOT(d, void _k_slotReplaceAll())
+    Q_DECLARE_PRIVATE(KReplace)
 };
 #endif
